@@ -1,10 +1,10 @@
 __title__ = 'starbase.__init__'
-__version__ = '0.2.7'
-__build__ = 0x000002
+__version__ = '0.3'
+__build__ = 0x000003
 __author__ = 'Artur Barseghyan'
 __copyright__ = 'Copyright (c) 2013 Artur Barseghyan'
 __license__ = 'GPL 2.0/LGPL 2.1'
-__all__ = ('Connection', 'Table')
+__all__ = ('Connection', 'Table',)
 
 from starbase.client.connection import Connection
 from starbase.client.table import Table
