@@ -9,7 +9,9 @@ import json
 
 from six import string_types, PY3
 
-from starbase.exceptions import InvalidArguments, ParseError, DoesNotExist
+from requests.models import HTTPError
+
+from starbase.exceptions import InvalidArguments, ParseError, DoesNotExist, IntegrityError
 from starbase.content_types import DEFAULT_CONTENT_TYPE
 from starbase.defaults import PERFECT_DICT
 from starbase.client.transport import HttpRequest
@@ -35,6 +37,7 @@ class Table(object):
         """
         self.connection = connection
         self.name = name
+        self.enable_if_exists_checks()
 
     def __repr__(self):
         return "<starbase.client.table.Table ({0})> on {1}".format(self.name, self.connection)
@@ -218,8 +221,9 @@ class Table(object):
         :param bool raw:
         :return dict:
         """
-        if not self.exists(fail_silently=fail_silently):
-            return None
+        if self.check_if_exists_on_row_fetch:
+            if not self.exists(fail_silently=fail_silently):
+                return None
 
         if perfect_dict is None:
             perfect_dict = self.connection.perfect_dict
@@ -237,7 +241,13 @@ class Table(object):
         if number_of_versions is not None:
             assert isinstance(number_of_versions, int)
             url += '?v={0}'.format(str(number_of_versions))
-        response = HttpRequest(connection=self.connection, url=url, decode_content=decode_content).get_response()
+
+        response = HttpRequest(
+            connection = self.connection,
+            url = url,
+            decode_content = decode_content,
+            fail_silently = fail_silently
+            ).get_response()
 
         response_content = response.content
 
@@ -317,15 +327,27 @@ class Table(object):
         >>>     filter_string = row_filter_string
         >>>     )
         """
-        if not self.exists(fail_silently=fail_silently):
-            return None
+        if self.check_if_exists_on_scanner_operations:
+            if not self.exists(fail_silently=fail_silently):
+                return None
 
         if perfect_dict is None:
             perfect_dict = self.connection.perfect_dict
 
-        scanner = self._scanner(filter_string=filter_string, data=scanner_config)
-        res = scanner.results(perfect_dict=perfect_dict, with_row_id=with_row_id, raw=raw)
-        scanner.delete ()
+        try:
+            scanner = self._scanner(filter_string=filter_string, data=scanner_config, fail_silently=fail_silently)
+        except HTTPError as e:
+            if fail_silently:
+                return []
+            raise DoesNotExist(_("""Table "{0}" does not exist.""".format(self.name)))
+
+        if scanner:
+            res = scanner.results(perfect_dict=perfect_dict, with_row_id=with_row_id, raw=raw)
+            scanner.delete ()
+        else:
+            if fail_silently:
+                return None
+            raise DoesNotExist(_("""Table "{0}" does not exist.""".format(self.name)))
 
         if flat:
             res = list(res)
@@ -394,8 +416,9 @@ class Table(object):
         :param bool fail_silently:
         :return int:
         """
-        if not self.exists(fail_silently=fail_silently):
-            return None
+        if self.check_if_exists_on_row_insert:
+            if not self.exists(fail_silently=fail_silently):
+                return None
 
         url = self._build_put_url(row, columns)
 
@@ -435,7 +458,7 @@ class Table(object):
         return self._put(row=row, columns=columns, timestamp=timestamp, fail_silently=fail_silently)
 
     def _scanner(self, batch_size=None, start_row=None, end_row=None, start_time=None, end_time=None, \
-                 filter_string=None, data=''):
+                 filter_string=None, data='', fail_silently=True):
         """
         Creates a scanner instance.
 
@@ -452,10 +475,18 @@ class Table(object):
         if filter_string is not None:
             data = {"filter": filter_string}
 
-        response = HttpRequest(connection=self.connection, url=url, data=data, method=PUT).get_response()
+        response = HttpRequest(
+            connection = self.connection,
+            url = url,
+            data = data,
+            method = PUT,
+            fail_silently = fail_silently
+            ).get_response()
+
         scanner_url = response.raw.headers.get('location')
 
-        return Scanner(table=self, url=scanner_url)
+        if scanner_url:
+            return Scanner(table=self, url=scanner_url)
 
     def _post(self, row, columns, timestamp=None, encode_content=True, fail_silently=True):
         """
@@ -468,8 +499,9 @@ class Table(object):
         :param bool fail_silently:
         :return int:
         """
-        if not self.exists(fail_silently=fail_silently):
-            return None
+        if self.check_if_exists_on_row_update:
+            if not self.exists(fail_silently=fail_silently):
+                return None
 
         url = self._build_put_url(row, columns)
 
@@ -646,12 +678,12 @@ class Table(object):
     metadata = regions
     metadata.__doc__ = regions.__doc__
 
-    def create(self, *columns):
+    def create(self, *columns, **kwargs):
         """
         Creates a table schema. If not successful, returns appropriate HTTP error status code. If successful,
         returns HTTP 201 status.
 
-        :param list *columns: List of columns (plain strins).
+        :param list *columns: List of columns (plain strings).
         :return int: HTTP response status code (201 on success). Returns boolean False on failure.
 
         :example:
@@ -660,13 +692,26 @@ class Table(object):
         >>> table = connection.table('table1')
         >>> table.create('column1', 'column2')
         """
+        fail_silently = kwargs.get('fail_silently', True)
+
         # If table exists, return False
-        if self.exists():
-            return False
+        if self.check_if_exists_on_schema_operations:
+            if self.exists():
+                if fail_silently:
+                    return False
+                else:
+                    raise IntegrityError("Table ``{0}`` already exists".format(self.name))
 
         url, data = self._get_data_for_table_create_or_update(columns)
 
-        response = HttpRequest(connection=self.connection, url=url, data=data, method=PUT).get_response()
+        response = HttpRequest(
+            connection = self.connection,
+            url = url,
+            data = data,
+            method = PUT,
+            fail_silently = fail_silently
+            ).get_response()
+
         return response.status_code
 
     def _get_data_for_table_create_or_update(self, columns):
@@ -691,31 +736,39 @@ class Table(object):
 
         return url, data
 
-    def _update_schema(self, columns, method=None):
+    def _update_schema(self, columns, method=None, fail_silently=True):
         """
         Updates current table schema. If not successful, returns appropriate HTTP error status code. If
         successful, returns HTTP 200 status or boolean False if table does not exist.
 
-        :param list columns: List of columns (plain strins).
+        :param list columns: List of columns (plain strings).
         :param str method: HTTP method (GET, POST, PUT, DELETE).
         :return int: HTTP response status code.
         """
-        if not self.exists():
-            return False
+        if self.check_if_exists_on_schema_operations:
+            if not self.exists(fail_silently=fail_silently):
+                return False
 
         if method is None:
             method = POST
 
         url, data = self._get_data_for_table_create_or_update(columns)
 
-        response = HttpRequest(connection=self.connection, url=url, data=data, method=method).get_response()
+        response = HttpRequest(
+            connection = self.connection,
+            url = url,
+            data = data,
+            method = method,
+            fail_silently = fail_silently
+            ).get_response()
+
         return response.status_code
 
     def _replace_schema(self, columns):
         """
         Replaces the table schema.
 
-        :param list columns: List of columns (plain strins). If not successful, returns appropriate HTTP error
+        :param list columns: List of columns (plain strings). If not successful, returns appropriate HTTP error
             status code. If successful, returns HTTP 200 status or boolean False if table does not exist.
         :return int: HTTP response status code.
         """
@@ -727,7 +780,7 @@ class Table(object):
         successful, returns HTTP 200 status.
 
         :param str name: Table name.
-        :param list *columns: List of columns (plain strins) to ADD.
+        :param list *columns: List of columns (plain strings) to ADD.
         :return int: HTTP response status code (200 on success).
 
         :example:
@@ -749,7 +802,7 @@ class Table(object):
         successful, returns HTTP 201 status.
 
         :param str name: Table name.
-        :param list *columns: List of columns (plain strins) to REMOVE.
+        :param list *columns: List of columns (plain strings) to REMOVE.
         :return int: HTTP response status code (201 on success).
 
         :example:
@@ -788,7 +841,48 @@ class Table(object):
         >>> batch.insert('row3', {'column1': {'id': '13', 'name': 'Some name'}, 'column2': {'id': '23', 'age': '323'}})
         >>> batch.commit(finalize=True)
         """
-        if not self.exists(fail_silently=fail_silently):
-            return None
+        if self.check_if_exists_on_batch_operations:
+            if not self.exists(fail_silently=fail_silently):
+                return None
 
         return Batch(table=self, size=size)
+
+    @property
+    def check_if_exists_on_schema_operations(self):
+        return True
+
+    @property
+    def check_if_exists_on_batch_operations(self):
+        return True
+
+    def disable_row_operation_if_exists_checks(self):
+        """
+        Disables `exists` method on row operations.
+        """
+        self.check_if_exists_on_row_fetch = False
+        self.check_if_exists_on_row_insert = False
+        self.check_if_exists_on_row_remove = False
+        self.check_if_exists_on_row_update = False
+
+    def enable_row_operation_if_exists_checks(self):
+        """
+        Enables `exists` method on row operations. The opposite of `disable_row_operation_if_exists_checks`.
+        """
+        self.check_if_exists_on_row_fetch = True
+        self.check_if_exists_on_row_insert = True
+        self.check_if_exists_on_row_remove = True
+        self.check_if_exists_on_row_update = True
+
+    def disable_if_exists_checks(self):
+        """
+        Skips calling the `exists` method on any operation.
+        """
+        self.disable_row_operation_if_exists_checks()
+        self.check_if_exists_on_scanner_operations = False
+
+    def enable_if_exists_checks(self):
+        """
+        Enables `exists` method on any operation. The opposite of `disable_if_exists_checks`.
+        """
+        self.enable_row_operation_if_exists_checks()
+        self.check_if_exists_on_scanner_operations = True
